==> gammu_1.37.0.orig.tar.xz: gammu-1.37.0/libgammu/phone/nokia/dct4s40/6510/6510file.h <==

GSM_Error N6510_GetFileSystemStatus		(GSM_StateMachine *s, GSM_FileSystemStatus *status);
GSM_Error N6510_GetNextFileFolder		(GSM_StateMachine *s, GSM_File *File, gboolean start);
GSM_Error N6510_GetFolderListing		(GSM_StateMachine *s, GSM_File *File, gboolean start);
GSM_Error N6510_AddFolder			(GSM_StateMachine *s, GSM_File *File);
GSM_Error N6510_DeleteFolder			(GSM_StateMachine *s, unsigned char *ID);
GSM_Error N6510_GetFilePart			(GSM_StateMachine *s, GSM_File *File, int *Handle, int *Size);
GSM_Error N6510_AddFilePart			(GSM_StateMachine *s, GSM_File *File, int *Pos, int *Handle);
GSM_Error N6510_DeleteFile			(GSM_StateMachine *s, unsigned char *ID);
GSM_Error N6510_SetFileAttributes		(GSM_StateMachine *s, GSM_File *File);
GSM_Error N6510_GetNextRootFolder		(GSM_StateMachine *s, GSM_File *File);
GSM_Error N6510_GetMMSFolders			(GSM_StateMachine *s, GSM_MMSFolders *folders);
GSM_Error N6510_GetNextMMSFileInfo		(GSM_StateMachine *s, unsigned char *FileID, int *MMSFolder, gboolean start);
GSM_Error N6510_GetFilesystemSMSFolders		(GSM_StateMachine *s, GSM_SMSFolders *folders);
GSM_Error N6510_GetNextFilesystemSMS		(GSM_StateMachine *s, GSM_MultiSMSMessage *sms, gboolean start);

GSM_Error N6510_ReplyGetFileCRC12		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplySetAttrib2			(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplySetFileDate2		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyOpenFile2			(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyGetFileFolderInfo1		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyGetFileFolderInfo2		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyGetFileFolderListing2	(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyGetFileSystemStatus1	(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyGetFilePart12		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyAddFileHeader1		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyAddFilePart1		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyDeleteFile2		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyAddFolder1			(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyAddFolder2			(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyDeleteFolder2		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyDeleteFileFolder1		(GSM_Protocol_Message *msg, GSM_StateMachine *s);

==> gammu_1.42.0.orig.tar.xz: gammu-1.42.0/libgammu/phone/nokia/dct4s40/6510/6510file.h <==

GSM_Error N6510_GetFileSystemStatus		(GSM_StateMachine *s, GSM_FileSystemStatus *status);
GSM_Error N6510_GetNextFileFolder		(GSM_StateMachine *s, GSM_File *File, gboolean start);
GSM_Error N6510_GetFolderListing		(GSM_StateMachine *s, GSM_File *File, gboolean start);
GSM_Error N6510_AddFolder			(GSM_StateMachine *s, GSM_File *File);
GSM_Error N6510_DeleteFolder			(GSM_StateMachine *s, unsigned char *ID);
GSM_Error N6510_GetFilePart			(GSM_StateMachine *s, GSM_File *File, int *Handle, size_t *Size);
GSM_Error N6510_AddFilePart			(GSM_StateMachine *s, GSM_File *File, size_t *Pos, int *Handle);
GSM_Error N6510_DeleteFile			(GSM_StateMachine *s, unsigned char *ID);
GSM_Error N6510_SetFileAttributes		(GSM_StateMachine *s, GSM_File *File);
GSM_Error N6510_GetNextRootFolder		(GSM_StateMachine *s, GSM_File *File);
GSM_Error N6510_GetMMSFolders			(GSM_StateMachine *s, GSM_MMSFolders *folders);
GSM_Error N6510_GetNextMMSFileInfo		(GSM_StateMachine *s, unsigned char *FileID, int *MMSFolder, gboolean start);
GSM_Error N6510_GetFilesystemSMSFolders		(GSM_StateMachine *s, GSM_SMSFolders *folders);
GSM_Error N6510_GetNextFilesystemSMS		(GSM_StateMachine *s, GSM_MultiSMSMessage *sms, gboolean start);

GSM_Error N6510_ReplyGetFileCRC12		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplySetAttrib2			(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplySetFileDate2		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyOpenFile2			(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyGetFileFolderInfo1		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyGetFileFolderInfo2		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyGetFileFolderListing2	(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyGetFileSystemStatus1	(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyGetFilePart12		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyAddFileHeader1		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyAddFilePart1		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyDeleteFile2		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyAddFolder1			(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyAddFolder2			(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyDeleteFolder2		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
GSM_Error N6510_ReplyDeleteFileFolder1		(GSM_Protocol_Message *msg, GSM_StateMachine *s);
